/**
 ****************************************************************************************
 *
 * @file main.c
 *
 * @brief UART example for DA14580/581 SDK
 *
 * Copyright (C) 2012. Dialog Semiconductor Ltd, unpublished work. This computer 
 * program includes Confidential, Proprietary Information and is a Trade Secret of 
 * Dialog Semiconductor Ltd.  All use, disclosure, and/or reproduction is prohibited 
 * unless authorized in writing. All Rights Reserved.
 *
 * <bluetooth.support@diasemi.com> and contributors.
 *
 ****************************************************************************************
 */
#include <stdio.h>

#include "global_io.h"
#include "common_uart.h"
#include "user_periph_setup.h"
#include "systick.h"
//#include "gpio.h"
#include "pwm.h"

#define SYSTICK_PERIOD_US   50000     // period for systick timer in us, so 50000ticks = 50ms
#define SYSTICK_EXCEPTION   1           // generate systick exceptions

// PWM settings
#define TIMER_ON        1000
#define PWM_HIGH        500
#define PWM_LOW         200
#define ALL_NOTES       26


uint16_t cnt_50ms=0;
uint16_t cnt_500ms=0;
uint8_t f_500ms=0;
int i = 0,j=0;

void system_init(void);
void systick_isr(void); 
void systick_test(void);



const uint16_t notes[ALL_NOTES] = {1046,987,767,932,328,880,830,609,783,991,739,989,698,456,659,255,622,254,587,554,365,523,251,493,466,440};

	
/**
 ****************************************************************************************
 * @brief  Main routine of the UART example
 * 
 ****************************************************************************************
 */
int main (void)
{
		uint16_t data_1 = 0;
		uint16_t key_in_old = 0,key_in_new = 0;
		
		system_init();
    periph_init();
    systick_test();

    //Enables TIMER0,TIMER2 clock
    set_tmr_enable(CLK_PER_REG_TMR_ENABLED);

    //Sets TIMER0,TIMER2 clock division factor to 8, so TIM0 Fclk is F = 16MHz/8 = 2Mhz
    set_tmr_div(CLK_PER_REG_TMR_DIV_8);

    // initialize PWM with the desired settings
    timer0_init(TIM0_CLK_FAST, PWM_MODE_ONE, TIM0_CLK_NO_DIV);

    // set pwm Timer0 'On', Timer0 'high' and Timer0 'low' reload values
    timer0_set(TIMER_ON, PWM_HIGH, PWM_LOW);
    timer0_start();

	
		key_in_new = ((uint16_t)GPIO_GetPinStatus(GPIO_PORT_1,GPIO_PIN_1) << 1) + ((uint16_t)GPIO_GetPinStatus(GPIO_PORT_0,GPIO_PIN_6) << 0);
		key_in_new ^= 0x0003;
		key_in_old = key_in_new;
	
    while(1)
		{
			if (f_500ms)
			{
				f_500ms = 0;
				
				j = 1 - j;
				key_in_old = key_in_new;
				key_in_new = ((uint16_t)GPIO_GetPinStatus(GPIO_PORT_1,GPIO_PIN_1) << 1) + ((uint16_t)GPIO_GetPinStatus(GPIO_PORT_0,GPIO_PIN_6) << 0);
				key_in_new ^= 0x0003;

				if (key_in_new != key_in_old)
				{
					print_hword(key_in_new);
					printf_string("\n\r");
					
					switch (key_in_new)
					{
						case 1:
						if (i<25)
						{
							i++;
					print_hword(i);
					printf_string("= i\n\r");
        timer0_set_pwm_on_counter(0xFFFF);
        timer0_set_pwm_high_counter(notes[i]/3 * 2);
        timer0_set_pwm_low_counter(notes[i]/3);
						}
							break;
						case 2:
							if (i>0)
							{
								i--;
					print_hword(i);
					printf_string("= i\n\r");
        timer0_set_pwm_on_counter(0xFFFF);
        timer0_set_pwm_high_counter(notes[i]/3 * 2);
        timer0_set_pwm_low_counter(notes[i]/3);
							}
							break;
					}
				}

				if (j)
				{
        GPIO_SetActive(LED_PORT, LED_PIN);
				}
				else
				{
	       GPIO_SetInactive(LED_PORT, LED_PIN);
				}
			}
		}
}
/**
 ****************************************************************************************
 * @brief System Initiialization 
 *
 * 
 ****************************************************************************************
 */
void system_init(void)
{
    SetWord16(CLK_AMBA_REG, 0x00);                 // set clocks (hclk and pclk ) 16MHz
    SetWord16(SET_FREEZE_REG,FRZ_WDOG);            // stop watch dog    
    SetBits16(SYS_CTRL_REG,PAD_LATCH_EN,1);        // open pads
    SetBits16(SYS_CTRL_REG,DEBUGGER_ENABLE,1);     // open debugger
    SetBits16(PMU_CTRL_REG, PERIPH_SLEEP,0);       // exit peripheral power down
}

/**
 ****************************************************************************************
 * @brief Systick ISR routine 
 *
 * 
 ****************************************************************************************
 */
void systick_isr(void)
{
	
		cnt_50ms++;
		cnt_500ms++;
	
		if (cnt_500ms > 9)
		{
			f_500ms = 1;
		}

		/*
    if (i == 0)
    {
        GPIO_SetActive(LED_PORT, LED_PIN);
        i = 1;
    }
    else
    {
        GPIO_SetInactive(LED_PORT, LED_PIN);
        i = 0;
    }*/
}

/**
 ****************************************************************************************
 * @brief Systick Test routine 
 *
 * 
 ****************************************************************************************
 */
void systick_test(void)
{
    systick_register_callback(systick_isr);
    // Systick will be initialized to use a reference clock frequency of 1 MHz
    systick_start(SYSTICK_PERIOD_US, SYSTICK_EXCEPTION);
}
